//******************************************************************************
// unita JP_Windows
//
// - unita obsahuje funkce a procedury jejiz funkce souvisi s Windows
//
// Vytvoril: Pavel Cvrcek <jasnapaka@jasnapaka.com>
//           http://www.jasnapaka.com
//
// Poznamka: Tato unita vznikla puvodne pro potreby autora. Nektery kod byl
//           vytvoren jinymi autory. Pokud je autor znam, je zde uveden.
//
// Cast prevzata od: Pepr <support@peprsoft.cz>
//                   Slvek Rydval <rk@atrey.karlin.mff.cuni.cz>
//
// Posledni editace: 2003/08/13
//******************************************************************************

unit JP_Windows;

interface

uses Classes, Graphics;

// ** Public deklarace

// vymazani kose
function EmptyRecycleBin: boolean;
// vrati seznam bezicich procesu
function GetProcessList: TStringList;
// vrati seznam bezicich procesu pod NT
function GetProcessListNT: TStringList;
// vraci cestu ke slozkam Windows
function GetSpecialDir (id: byte): string;
// zmena pozadi ve Windows
procedure ChangeDesktopBackground (Cesta: string);
// zjisteni, zda-li je MSIE nainstalovan
function MSIEDetect (var verze: string): boolean;
// otevre okno Windows Exploreru 
procedure OpenExplorer (Cesta: string);
// vrati verzi Windows
function OSVersion: byte;
// nastaveni rozliseni monitoru
function SetScreenResolution (ScreenWidth, ScreenHeight: Integer): Longint;
// zobrazeni about boxu Windows
procedure ShowAboutBox (Aplikace: string; Copyright: string);
// zobrazeni dialogu vlastnosti souboru
procedure ShowProDialog (FileName: string);
function GetWindowsDir: string;

implementation

uses Forms, Registry, psapi, SysUtils, ShellApi, shlObj, Tlhelp32, Windows, WinSock;


//******************************************************************************
// ** Privatni procedury a funkce
//******************************************************************************


//******************************************************************************
// function GetTempDir
//
// - vraci cestu ke slozce Temp
//******************************************************************************

function GetTempDir: string;
var nbufferLength : DWord;
    lpBuffer : PChar;
begin
  nBufferLength := Max_path + 1;
  GetMem (lpBuffer, nBufferLength);
  try
    if GetTempPath(nBufferLength, lpBuffer) <> 0 then
    Result := StrPas(lpBuffer)
    else Result := '';
  finally
    FreeMem(lpBuffer);
  end;
end;


//******************************************************************************
// function GetWindowsDir
//
// - vraci adresar, kde jsou nainstalovany Windows
//******************************************************************************

function GetWindowsDir: string;
var WindowDir : array[0..255] of Char;
begin
  GetWindowsDirectory(WindowDir, 255);
  Result := StrPas(WindowDir);
end;


//******************************************************************************
// ** Public procedury a funkce
//******************************************************************************


//******************************************************************************
// function EmptyRecycleBin
//
// - vymaze kos Windows
//
// Vystup: true - akce se povedla
//         false - nastala chyba
//******************************************************************************

function EmptyRecycleBin: boolean;

const SHERB_NOCONFIRMATION = $00000001;
      SHERB_NOPROGRESSUI = $00000002;
      SHERB_NOSOUND = $00000004;

type TSHEmptyRecycleBin = function(Wnd: HWND; LPCTSTR: PChar;
                          DWord: Word): Integer; stdcall;
var SHEmptyRecycleBin: TSHEmptyRecycleBin;
    LibHandle : THandle;
begin
  SHEmptyRecycleBin:= nil;
  LibHandle := LoadLibrary(PChar('Shell32.dll'));
  if LibHandle <> 0 then
      @SHEmptyRecycleBin := GetProcAddress(LibHandle, 'SHEmptyRecycleBinA')
  else Result:= false;

  if @SHEmptyRecycleBin <> nil then begin
      SHEmptyRecycleBin(Application.Handle, '', SHERB_NOCONFIRMATION or
      SHERB_NOPROGRESSUI or SHERB_NOSOUND);
      Result:= true;
  end
  else Result:= false;
  FreeLibrary(LibHandle);
  @SHEmptyRecycleBin := nil;
end;


//******************************************************************************
// function GetProcessList
//
// - vrati seznam spustenych procesu
//******************************************************************************

function GetProcessList: TStringList;
var hSnapShot : THandle;
    pe32 : TPROCESSENTRY32;
    StringList: TStringList;
begin
  StringList:= TStringList.Create;
  hSnapShot := CreateToolHelp32SnapShot(TH32cs_snapprocess,0);
  pe32.dwSize := SizeOf(TPROCESSENTRY32);
  if Process32First(hSnapShot, pe32) then StringList.Add(extractFileName(pe32.szExeFile));
  while Process32Next(hSnapShot, pe32) do
  begin
    StringList.Add(extractFileName(pe32.szExeFile));
  end;
  CloseHandle (hSnapShot);
  Result:= StringList;
end;


//******************************************************************************
// function GetProcessListNT
//
// - vrati seznam spustenych procesu pod NT
//******************************************************************************

function GetProcessListNT: TStringList;

  function ProcessFileName(PID: DWORD): string;
  var
    Handle: THandle;
    Fullpath: boolean;
  begin
    Result := ''; Fullpath:= false;
    Handle := OpenProcess(PROCESS_QUERY_INFORMATION or PROCESS_VM_READ, False, PID);
    if Handle <> 0 then
    try
      SetLength(Result, MAX_PATH);
      if FullPath then
      begin
        if GetModuleFileNameEx(Handle, 0, PChar(Result), MAX_PATH) > 0 then
          SetLength(Result, StrLen(PChar(Result)))
        else
          Result := '';
      end
      else
      begin
        if GetModuleBaseNameA(Handle, 0, PChar(Result), MAX_PATH) > 0 then
          SetLength(Result, StrLen(PChar(Result)))
        else
          Result := '';
      end;
    finally
      CloseHandle(Handle);
    end;
  end;
  
var
    PIDs: array [0..1024] of DWORD;
    Needed: DWORD;
    I: Integer;
    FileName: string;
    StringList: TStringList;

begin
  StringList:= TStringList.Create;
  if EnumProcesses(@PIDs, SizeOf(PIDs), Needed) then
    begin
      for I := 0 to (Needed div SizeOf(DWORD)) - 1 do
        begin
          StringList.Add (ProcessFileName(PIDs[I]));
        end;
    end;
  Result:= StringList;
end;


//******************************************************************************
// function GetSpecialDir
//
// - vraci cestu ke specialnim adresarum Windows
//
// Vstup: id - ciselne vyjadreni adresare
// Vystup: - cesta k danemu adresari
//******************************************************************************

function GetSpecialDir (id: byte): string;
var gFolder : Integer;
    SFolder : pItemIDList;
    SpecialPath : Array[0..MAX_PATH] of Char;
begin
  gFolder:= 0;
  case id of
    1: gFolder:= CSIDL_DESKTOP;                         // Desktop
    2: gFolder:= CSIDL_PERSONAL;                        // Dokumenty
    3: gFolder:= CSIDL_FAVORITES;                       // Oblibene
    4: gFolder:= CSIDL_FONTS;                           // Fonty
    5: gFolder:= CSIDL_NETHOOD;                         // Okolni pocitace
    6: gFolder:= CSIDL_PROGRAMS;                        // Programy
    7: gFolder:= CSIDL_STARTUP;                         // Po spusteni
    8: gFolder:= CSIDL_RECENT;                          // Recent
    9: gFolder:= CSIDL_SENDTO;                          // SendTo
    10: gFolder:= CSIDL_STARTMENU;                      // Start
    11: gFolder:= CSIDL_APPDATA;                        // Data aplikaci
    12: gFolder:= CSIDL_COOKIES;                        // Cookies
    13: gFolder:= CSIDL_INTERNET_CACHE;                 // Internet Cache
    14: gFolder:= CSIDL_HISTORY;                        // Historie
    16: gFolder:= CSIDL_TEMPLATES;                      // Templates
    17: gFolder:= CSIDL_COMMON_DESKTOPDIRECTORY;        // Sdileny Desktop
    18: gFolder:= CSIDL_COMMON_FAVORITES;               // Sdilene Oblibene
    19: gFolder:= CSIDL_COMMON_STARTMENU;               // Sdileny Start
    20: gFolder:= CSIDL_COMMON_PROGRAMS;                // Sdileny Programy
    21: gFolder:= CSIDL_COMMON_STARTUP;                 // Sdileny Po spusteni
    else Result:= '';
  end;

  if (id <> 0) and (id <> 15) and (id <= 21) then
    begin
      SHGetSpecialFolderLocation(Application.Handle, gFolder, SFolder);
      SHGetPathFromIDList(SFolder, SpecialPath);
      Result:= StrPas(SpecialPath);
    end;
  if (id = 0) then Result:= GetWindowsDir;              // adresar Windows
  if (id = 15) then Result:= GetTempDir;                // Temp
  if (id = 22) then Result:= '';                        // nesmysl
end;


//******************************************************************************
// procedure ChangeDesktopBackground
//
// - zmeni pozadi ve Windows
//
// Vstup: Cesta - cesta s BMP obrazkem
//******************************************************************************

procedure ChangeDesktopBackground (Cesta: string);
begin
  SystemParametersInfo(SPI_SETDESKWALLPAPER, 0, PCHar(Cesta), 0);
end;


//******************************************************************************
// function MSIEDetect
//
// vraci informaci, zda-li je MSIE nainstalovan a pripadne i jeho verzi
//
// Vstup: verze - verze MSIE (jde na vystup)
//******************************************************************************

function MSIEDetect(var Verze: string): boolean;
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  with Reg do begin
    RootKey := HKEY_LOCAL_MACHINE;
    OpenKey('Software\Microsoft\Internet Explorer', False);
    if ValueExists('Version') then Verze := ReadString('Version')
    else Verze := '';
    CloseKey;
    Free;
  end;
  Result := Verze <> '';
end;


//******************************************************************************
// procedure OpenExplorer
//
// - otevre okno Windows Exploreru v pozadovanem adresari
//
// Vstup: Cesta - cesta k adresari
//******************************************************************************

procedure OpenExplorer (Cesta: string);
begin
  ShellExecute (Application.handle, 'explore', Pchar (Cesta), Nil, Nil, SW_SHOWNORMAL );
end;


//******************************************************************************
// function OSVersion
//
// - vrati verzi Windows
//******************************************************************************

function OSVersion: byte;
var OS : TOSVersionInfo;
begin
  OS.dwOSVersionInfoSize := SizeOf(OS);
  GetVersionEx(Os);
  case OS.dwPlatformId of
    VER_PLATFORM_WIN32S : Result:= 0;                           // Windows 3.1
    VER_PLATFORM_WIN32_WINDOWS :
    case Os.dwMinorVersion of
      0..9 : begin
               if trim(Os.szCSDVersion) = 'B' then  Result:= 1  // Windows 95 OSR2
               else Result:= 2;                                 // Windows 95
             end;
    10..89 : begin
               if trim(Os.szCSDVersion) = 'A' then Result:= 4   // Windows 98 SE
               else Result:= 3;                                 // Windows 98
             end;
        90 : Result:= 5;                                        // Windows ME
     end;
    VER_PLATFORM_WIN32_NT :
    case OS.dwMajorVersion of
         3 : Result:= 6;                                        // Windows NT 3
         4 : Result:= 7;                                        // Windows NT 4
         5 : begin
               case OS.dwMinorVersion of
                    0 : Result:= 8;                             // Windows 2000
                    1 : Result:= 9;                             // Windows XP
                    2 : Result:= 10;                            // Windows 2003
               end;
     end;
  end;
  end;
end;


//******************************************************************************
// function SetScreenResolution
//
// - nastavi rozliseni monitoru
//
// Vstup: ScreenWidth - napr. 800
//        ScreenHeight - napr. 600
//******************************************************************************

function SetScreenResolution(ScreenWidth, ScreenHeight: Integer): Longint;
var LDeviceMode: TDeviceMode;
begin
  LDeviceMode.dmSize := SizeOf(TDeviceMode);
  LDeviceMode.dmPelsWidth := ScreenWidth;
  LDeviceMode.dmPelsHeight := ScreenHeight;
  LDeviceMode.dmFields := DM_PELSWIDTH or DM_PELSHEIGHT;
  Result := ChangeDisplaySettings(LDeviceMode, CDS_UPDATEREGISTRY);
end;


//******************************************************************************
// procedure ShowAboutBox
//
// - zobrazi About Box Windows
//
// Vstup: Aplikace - jmeno aplikace
//        Copyright - copyright
//******************************************************************************

procedure ShowAboutBox (Aplikace: string; Copyright: string);
begin
  ShellAbout (Application.Handle, PChar (Aplikace), PChar (Copyright),
  Application.Icon.Handle);
end;


//******************************************************************************
// procedure ShowProDialog
//
// - zobrazi dialog s vlastnostmi souboru
//
// Vstup: FileName - jmeno vstupniho souboru
//******************************************************************************

procedure ShowProDialog (FileName: string);
var SInfo: TShellExecuteInfo;
const EXE_INFO : String = 'properties';
begin
  FillChar(SInfo, SizeOf(SInfo), 0);
  SInfo.cbSize := SizeOf(SInfo);
  SInfo.lpFile := PChar(FileName);
  SInfo.lpVerb := PChar(EXE_INFO);
  SInfo.fMask := SEE_MASK_INVOKEIDLIST;
  ShellExecuteEx(@SInfo);
end;


end.
