//******************************************************************************
// Mozilla Backup
//
// - unita obsahujici hlavni funkce a procedury programu
//
// Programoval:         Pavel Cvrcek <jasnapaka@jasnapaka.com>
// Verze:               1.2a
// Posledni editace:    2004/01/02
//******************************************************************************

{
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
}

unit funkce;

interface                   

// pridani noveho profilu
procedure Add_profil;
// provede se inicializace dialogu (krom hlavniho)
procedure Dialogy_init;
// vytvori novy profil Mozilly
procedure Create_profil;
// provede detekci aplikaci, ktere se mohou zalohovat
procedure DetekceKomponent;
// provede detekci profilu Mozilly
procedure DetekceProfilu;
// detekuje soucasti, ktere lze zalohovat
procedure DetekceSoucasti;
// detekuje soucasti, ktere lze obnovit
procedure DetekceSoucastiSoubor;
// vrati vychozi jmeno zalozniho souboru
function GetDefaultFilename: string;
// vyber Open ci Save Dialogu
procedure ChooseDialog;
// detekce spustene Mozilly
function IsRunning: boolean;
// detekuje, zda-li se jedna o soubor se zalohou
function IsValidFile (Soubor: string):boolean;
// "vynuluje" checkboxy
procedure NastavCheckboxy;
// overi platnosto profilu
function Over_profil (Adresar: string):boolean;
// overi, zda-li byl nalezen nejaky program
procedure Over_program;
// overi, zda-li je vybrana aplikace na provedeni zalohy
procedure Over_vyber;
// overi, zda-li je vybran nejaky profil
procedure Over_vyber_profilu;
// ukonceni programu  - krizek na formulari
procedure Ukonceni_programu (var CanClose: boolean);
// zjisteni, zda-li se muze zacit se zalohovanim (resp. obnovou)
function Zacatek_zalohovani: boolean;

implementation

uses adresar, Classes, controls, dialogs, forms, hlavni, chyby, input_dialog, jp_windows, registry, ShellApi, StdCtrls, StrUtils, sysutils, windows, bsPolyglotUn;

var Registr: TRegistry;


//******************************************************************************
// procedure Add_profil
//
// - prida externi profil
//******************************************************************************

procedure Add_profil;
begin
  if FileExists (Form3.ShellTreeView1.Path + '\prefs.js')
  then
    begin
      // vymazat predchozi externi
      if Length (Externi_profil.Jmeno) <> 0 then Form1.ListBox2.Items.Delete(Form1.ListBox2.Count - 1);

      // pridat externi
      Form1.ListBox2.Items.Add(TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_PROFIL_NAME', 'External profile'));
      Externi_profil.Jmeno:= TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_PROFIL_NAME', 'External profile');
      Externi_profil.Cesta:= Form3.ShellTreeView1.Path;
    end
  else Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_BAD_PROFIL2', 'This directory doesn''t contains Mozilla profile.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);
end;


//******************************************************************************
// procedure Dialogy_init
//
// - provede jazykovou inicializaci dialogu (krom hlavniho)
//******************************************************************************

procedure Dialogy_init;
begin
  Form2.Caption:= TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_NEW_PROFIL', 'New profile');
  Form2.Label1.Caption:= TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_NEW_PROFIL_NAME', 'Insert the new profile name:');
  Form2.Button1.Caption:= TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_BUTTON_OK', 'OK');
  Form2.Button2.Caption:= TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_BUTTON_2', 'Cancel');
  Form2.Edit1.Text:= '';
  Form2.Potvrzeno:= false;
  Form2.Font.Charset:= Form1.Jazyk;
end;

//******************************************************************************
// procedure Create_profil
//
// - vytvori novy profil Mozilly
//******************************************************************************

procedure Create_profil;
var Retezec: string;
    Vysledek: boolean;
begin
  // Vytvoreni noveho profilu
  Dialogy_init;                 // inicializace dialogu

  Form2.ShowModal;

  Retezec:= LowerCase (Form2.Edit1.Text);
  if Form2.Potvrzeno = true then
    begin
      Vysledek:= true;

      if Pos ('\', Retezec) > 0 then Vysledek:= false;
      if Pos ('/', Retezec) > 0 then Vysledek:= false;
      if Pos ('!', Retezec) > 0 then Vysledek:= false;
      if Pos ('?', Retezec) > 0 then Vysledek:= false;
      if Pos ('<', Retezec) > 0 then Vysledek:= false;
      if Pos ('>', Retezec) > 0 then Vysledek:= false;
      if Pos ('*', Retezec) > 0 then Vysledek:= false;
      if Pos (':', Retezec) > 0 then Vysledek:= false;
      if Pos ('"', Retezec) > 0 then Vysledek:= false;

      if (Vysledek = true) and (Length (Retezec) > 0) then  // byl zadan nejaky profil
        begin
          if not DirectoryExists (Form1.Slozka_data + '\Profiles\' + Retezec) then
            begin
              case Form1.Typ_programu of
                1: ShellExecute (Application.handle, 'open', Pchar (Programy[1].Cesta + '\mozilla.exe'), Pchar ('-CreateProfile ' + Retezec), Nil, SW_SHOWNORMAL );
                2: ShellExecute (Application.handle, 'open', Pchar (Programy[2].Cesta + '\MozillaFirebird.exe'), Pchar ('-CreateProfile ' + Retezec), Nil, SW_SHOWNORMAL );
                3: ShellExecute (Application.handle, 'open', Pchar (Programy[3].Cesta + '\thunderbird.exe'), Pchar ('-CreateProfile ' + Retezec), Nil, SW_SHOWNORMAL );
              end;
            end
         else Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_PROFIL_EXIST', 'There is a profile with this name.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);
        end
      else Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_NO_NAME', 'No profile name was inserted.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);
    end;
end;

//******************************************************************************
// procedure SearchProgram
//
// - vyhleda program v registru (pokud tam je)
//
// Vstup: Cesta - cesta v registrech
//        Klic - klic, ktery se prohledava
//        Program - typ programu
//******************************************************************************

procedure SearchProgram (Cesta: string; Klic: string; Typ: byte);
begin
  if Registr.OpenKey(Cesta, false) then
    begin
      if Registr.ValueExists (Klic)then
        begin
          Programy[Typ].Nalezen:= true;
          Programy[Typ].Verze:= Registr.ReadString (Klic);
          case Typ of
            1: Form1.ListBox1.Items.Add ('Mozilla ' + Programy[Typ].Verze);
            2: Form1.ListBox1.Items.Add ('Mozilla Firebird ('+ Programy[Typ].Verze + ')');
            3: Form1.ListBox1.Items.Add ('Mozilla Thunderbird ('+ Programy[Typ].Verze + ')');
          end;
        end
      else Form1.ListBox1.Items.Add('Mozilla');
    end
  else
    begin
      //** nalezeni profilu odinstalovane aplikace
      case Typ of
        1: if (DirectoryExists (GetSpecialDir (11) + '\Mozilla\Profiles') = true) and (Programy[1].Nalezen = false)
           then Form1.ListBox1.Items.Add('Mozilla ' + TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_ONLYPROFIL', '(profiles only)'));
        2: if (DirectoryExists (GetSpecialDir (11) + '\Phoenix\Profiles') = true) and (Programy[2].Nalezen = false)
           then Form1.ListBox1.Items.Add('Mozilla Firebird ' + TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_ONLYPROFIL', '(profiles only)'));
        3: if (DirectoryExists (GetSpecialDir (11) + '\Thunderbird\Profiles') = true) and (Programy[3].Nalezen = false)
           then Form1.ListBox1.Items.Add('Mozilla Thunderbird ' + TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_ONLYPROFIL', '(profiles only)'));
      end;
    end;
  Registr.CloseKey;
end;


//******************************************************************************
// procedure SearchDirectory
//
// - vyhleda cestu k zadanemu programu
//
// Vstup: Cesta - cesta v registrech
//        Klic - klic, ktery se prohledava
//        Program - typ programu
//******************************************************************************

procedure SearchDirectory (Cesta: string; Klic: string; Typ: byte);
begin
  if Registr.OpenKey(Cesta, false) then
    begin
      if Registr.ValueExists(Klic) then
      Programy[Typ].Cesta:= Registr.ReadString (Klic);
    end;
  Registr.CloseKey;
end;

//******************************************************************************
// procedure DetekceKomponent
//
// - detekce komponent, ktere jsou vhodne k zalohovani (programy)
//******************************************************************************

procedure DetekceKomponent;
begin
  // otevreni registru
  Registr:= TRegistry.Create;
  Registr.Access:= KEY_READ;
  Registr.RootKey:= HKEY_LOCAL_MACHINE;

  // ** Detekce Mozilly
  Form1.ListBox1.Clear;
  SearchProgram ('SOFTWARE\mozilla.org\Mozilla', 'CurrentVersion', 1);
  SearchDirectory ('SOFTWARE\mozilla.org\Mozilla\' + Programy[1].Verze + '\Main', 'Install Directory', 1);

  // ** Detekce Mozilly Firebird
  SearchProgram ('SOFTWARE\mozilla.org\Firebird', 'Date', 2);
  SearchDirectory ('SOFTWARE\mozilla.org\Firebird\', 'InstallDir', 2);

  // ** Detekce Mozilly Thunderbird
  SearchProgram ('SOFTWARE\mozilla.org\Thunderbird', 'Date', 3);
  SearchDirectory ('SOFTWARE\mozilla.org\Thunderbird\', 'InstallDir', 3);

  // ukonceni prace s registry
  Registr.CloseKey;
  Registr.Destroy;
end;


//******************************************************************************
// procedure DetekceProfilu
//
// - detekce profilu Mozilly
//******************************************************************************

procedure DetekceProfilu;
var Search: TSearchRec;
    Typ: string;
begin
  // co bylo vybrano?
  if Pos ('Mozilla', Form1.ListBox1.Items.Strings[Form1.ListBox1.ItemIndex]) > 0 then
    begin
      Typ:= 'Mozilla';
      Form1.Typ_programu:= 1;
    end;
  if Pos ('Firebird', Form1.ListBox1.Items.Strings[Form1.ListBox1.ItemIndex]) > 0 then
    begin
      Typ:= 'Phoenix';
      Form1.Typ_programu:= 2;
    end;
  if Pos ('Thunderbird', Form1.ListBox1.Items.Strings[Form1.ListBox1.ItemIndex]) > 0 then
    begin
      Typ:= 'Thunderbird';
      Form1.Typ_programu:= 3;
    end;
    
  // nacteni profilu
  Form1.ListBox2.Clear;
  Form1.Slozka_data:= GetSpecialDir (11) + '\' + Typ;

  // adresar, ktery je nestandardne ulozen jinde ve Windows XP
  if not DirectoryExists (Form1.Slozka_data) then Form1.Slozka_data:= GetWindowsDir + '\' + Typ;

  if DirectoryExists (Form1.Slozka_data + '\Profiles') then
    begin
      // nacteni Profilu
      if FindFirst (Form1.Slozka_data + '\Profiles\*.*', faDirectory, Search) = 0 then
        begin
          Repeat
            if (Search.Name <> '.') and (Search.Name <> '..') and
               (Over_Profil (Form1.Slozka_data + '\Profiles\' + Search.Name) = true) then
               Form1.ListBox2.Items.Add (Search.Name);
          Until FindNext (Search) <> 0;
         SysUtils.FindClose (Search);
        end;
    end;

  // pridani externiho profilu
  if Length (Externi_profil.Jmeno) <> 0 then Form1.ListBox2.Items.Add(Externi_profil.Jmeno);
end;


//******************************************************************************
// procedure DetekceSoucasti
//
// - detekuje soucasti, ktere lze zalohovat
//******************************************************************************

procedure DetekceSoucasti;
var Vyhledej: TSearchRec;
    Slozka_data1: string;
    Profil_nalezen: boolean;
begin
  Profil_nalezen:= false;
  // nastaveni cesty k profilu
  if Form1.ListBox2.Items.Strings[Form1.ListBox2.ItemIndex] <> TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_PROFIL_NAME', 'External profile') then
    begin
      Slozka_data1:= Form1.Slozka_data + '\Profiles\' +
                     Form1.ListBox2.Items.Strings[Form1.ListBox2.ItemIndex];
      if FindFirst (Slozka_data1 + '\*.*', faDirectory, Vyhledej) = 0 then
        begin
          Repeat
            if FileExists (Slozka_data1 + '\' + Vyhledej.Name + '\prefs.js') = true then Profil_nalezen:= true;
          Until (Profil_nalezen = true) or (FindNext (Vyhledej) <> 0);
        end;
    end
  else Vyhledej.Name:= TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_PROFIL_NAME', 'External profile');

  if Length (Vyhledej.Name) > 0 then // nalezen podadresar
    begin
      if Form1.ListBox2.Items.Strings[Form1.ListBox2.ItemIndex] <> TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_PROFIL_NAME', 'External profile') then
        begin
          Slozka_data1:= Slozka_data1 + '\' + Vyhledej.Name + '\'; // nalezen profil
          SysUtils.FindClose (Vyhledej);
        end
      else Slozka_data1:= Externi_profil.Cesta + '\';


      // ** nyni se vyhledaji soucasti
      // obecna konfigurace
      if FileExists (Slozka_data1 + 'prefs.js') then Form1.CheckBox1.Checked:= true
      else Form1.CheckBox1.Enabled:= false;

      // emailova posta
      if (DirectoryExists (Slozka_data1 + 'Mail')) or (DirectoryExists (Slozka_data1 + 'ImapMail'))
         or (DirectoryExists (Slozka_data1 + 'News')) then Form1.CheckBox2.Checked:= true
      else Form1.CheckBox2.Enabled:= false;

      // kontakty
      if FileExists (Slozka_data1 + 'abook.mab') then Form1.CheckBox3.Checked:= true
      else Form1.CheckBox3.Enabled:= false;

      // bookmarky
      if FileExists (Slozka_data1 + 'bookmarks.html') then Form1.CheckBox4.Checked:= true
      else Form1.CheckBox4.Enabled:= false;

      // historie
      if FileExists (Slozka_data1 + 'history.dat') then Form1.CheckBox5.Checked:= true
      else Form1.CheckBox5.Enabled:= false;

      // panely
      if FileExists (Slozka_data1 + 'panels.rdf') then Form1.CheckBox6.Checked:= true
      else Form1.CheckBox6.Enabled:= false;

      // uzivatelske styly
      if FileExists (Slozka_data1 + 'chrome\userChrome.css') or FileExists (Slozka_data1 + 'chrome\userContent.css')
      then Form1.CheckBox8.Checked:= true else Form1.CheckBox8.Enabled:= false;

      // ulozena hesla
      if FindFirst (Slozka_data1 + '\*.s', faAnyFile, Vyhledej) = 0 then Form1.CheckBox9.Checked:= true
      else Form1.CheckBox9.Enabled:= false;
      SysUtils.FindClose(Vyhledej);

      // cookies
      if FileExists (Slozka_data1 + 'cookies.txt') then Form1.CheckBox10.Checked:= true
      else Form1.CheckBox10.Enabled:= false;

      // doplnene formulare
      if FindFirst (Slozka_data1 + '\*.w', faAnyFile, Vyhledej) = 0 then Form1.CheckBox11.Checked:= true
      else Form1.CheckBox11.Enabled:= false;
      SysUtils.FindClose(Vyhledej);

      // stahovani souboru
      if FileExists (Slozka_data1 + 'downloads.rdf') then Form1.CheckBox12.Checked:= true
      else Form1.CheckBox12.Enabled:= false;

      // certifikatu
      if FileExists (Slozka_data1 + 'key3.db') or FileExists (Slozka_data1 + 'cert7.db') or
         FileExists (Slozka_data1 + 'cert8.db') or FileExists (Slozka_data1 + 'secmod.db')
      then Form1.CheckBox13.Checked:= true else Form1.CheckBox13.Enabled:= false;
      
    end
  else
    begin
      // uzivatelsky profil je poskozen
      Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_BAD_PROFIL', 'The selected user profile is corrupted. The program will exit.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);
      Halt (1);
    end;
end;


//******************************************************************************
// procedure DetekceSoucastiSoubor
//
// - detekuje soucasti, ktere obsahuje zalozni soubor
//******************************************************************************

procedure DetekceSoucastiSoubor;
var F: textfile;
    S: string;
    I: byte;
begin

try
  // stary format souboru
  IsValidFile (Form1.Vyst_soubor);

  if Form1.Verze_souboru = 1 then AssignFile (F, Form1.Vyst_soubor);
  if Form1.Verze_souboru = 2 then
    begin
      //if Form1.ZipMaster1.

      Form1.ZipMaster1.ZipFileName:= Form1.Vyst_soubor;
      Form1.ZipMaster1.FSpecArgs.Add('indexfile.txt');
      Form1.ZipMaster1.ExtrBaseDir:= GetSpecialDir (2);

      Form1.ZipMaster1.Extract;

      AssignFile (F, GetSpecialDir (2) + '\indexfile.txt');
    end;
  Reset (F);
  for I:= 1 to 5 do
    Readln (F, S);
  CloseFile (F);
  S:= Trim (S);

  Form1.CheckBox1.Enabled:= false;
  if S[1] = 'Y' then Form1.CheckBox1.Checked else Form1.CheckBox1.Checked:= false;

  if S[2] = 'Y' then
    begin
      Form1.CheckBox2.Checked:= true;
      Form1.CheckBox2.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox2.Checked:= false;
      Form1.CheckBox2.Enabled:= false;
    end;

  if S[3] = 'Y' then
    begin
      Form1.CheckBox3.Checked:= true;
      Form1.CheckBox3.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox3.Checked:= false;
      Form1.CheckBox3.Enabled:= false;
    end;

  if S[4] = 'Y' then
    begin
      Form1.CheckBox4.Checked:= true;
      Form1.CheckBox4.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox4.Checked:= false;
      Form1.CheckBox4.Enabled:= false;
    end;

  if S[5] = 'Y' then
    begin
      Form1.CheckBox5.Checked:= true;
      Form1.CheckBox5.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox5.Checked:= false;
      Form1.CheckBox5.Enabled:= false;
    end;

  if S[6] = 'Y' then
    begin
      Form1.CheckBox6.Checked:= true;
      Form1.CheckBox6.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox6.Checked:= false;
      Form1.CheckBox6.Enabled:= false;
    end;

  if S[7] = 'Y' then
    begin
      Form1.CheckBox8.Checked:= true;
      Form1.CheckBox8.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox8.Checked:= false;
      Form1.CheckBox8.Enabled:= false;
    end;

  if S[8] = 'Y' then
    begin
      Form1.CheckBox9.Checked:= true;
      Form1.CheckBox9.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox9.Checked:= false;
      Form1.CheckBox9.Enabled:= false;
    end;

  if S[9] = 'Y' then
    begin
      Form1.CheckBox10.Checked:= true;
      Form1.CheckBox10.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox10.Checked:= false;
      Form1.CheckBox10.Enabled:= false;
    end;

  if S[10] = 'Y' then
    begin
      Form1.CheckBox11.Checked:= true;
      Form1.CheckBox11.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox11.Checked:= false;
      Form1.CheckBox11.Enabled:= false;
    end;

  if S[11] = 'Y' then
    begin
      Form1.CheckBox12.Checked:= true;
      Form1.CheckBox12.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox12.Checked:= false;
      Form1.CheckBox12.Enabled:= false;
    end;

  // certifikat - byl dodan pozdeji
  if (Length (S) > 11) and (S[12] = 'Y') then
    begin
      Form1.CheckBox13.Checked:= true;
      Form1.CheckBox13.Enabled:= true;
    end
  else
    begin
      Form1.CheckBox13.Checked:= false;
      Form1.CheckBox13.Enabled:= false;
    end;

except
  on E:EInOutError do     // nastala nejaka vyjimka
    begin
      Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_NOT_FOUND', 'A critical error occurred while accessing the file. The program will exit.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);
      Halt (1);
    end;
end;
end;


//******************************************************************************
// function GetDefaultFileName
//
// - vraci vychozi jmeno pro zalozni soubor
//******************************************************************************

function GetDefaultFilename: string;
var Datum: string;
begin
  Datum:= SysUtils.StringReplace (DateToStr (Now), '/', '.', [rfReplaceAll]);
  case Form1.Typ_programu of
    1: if Length (Programy[1].Verze) <> 0 then Result:= GetSpecialDir (2) + '\Mozilla ' + Programy[1].Verze + ' - ' + Datum + '.pcv'
       else Result:= GetSpecialDir (2) + '\Mozilla - ' + Datum + '.pcv';
    2: if Length (Programy[2].Verze) <> 0 then Result:= GetSpecialDir (2) + '\Firebird(' + Programy[2].Verze + ') - ' + Datum + '.pcv'
       else Result:= GetSpecialDir (2) + '\Firebird - ' + Datum + '.pcv';
    3: if Length (Programy[3].Verze) <> 0  then Result:= GetSpecialDir (2) + '\Thunderbird(' + Programy[3].Verze + ') - ' + Datum + '.pcv';
       else Result:= GetSpecialDir (2) + '\Thunderbird - ' + Datum + '.pcv';
  end;
end;


//******************************************************************************
// procedure ChooseDialog
//
// - vyber Open ci Save dialogu
//******************************************************************************

procedure ChooseDialog;
begin
  // vyber souboru
  if Form1.Akce = 1 then
    begin
      // nastaveni vychozi cesty
      Form1.SaveDialog1.InitialDir:= ExtractFilePath (Form1.Vyst_soubor);
      Form1.SaveDialog1.FileName:= ExtractFileName (Form1.Vyst_soubor);

      if Form1.SaveDialog1.Execute then
        begin
           Form1.Vyst_soubor:= ChangeFileExt(Form1.SaveDialog1.FileName,'.pcv');
           if Length (Form1.Vyst_soubor) < 40 then Form1.StaticText3.Caption:= Form1.Vyst_soubor
           else
             begin
               Form1.StaticText3.Caption:= Copy (Form1.Vyst_soubor, 1, 3) + '...' + Copy (Form1.Vyst_soubor, Length (Form1.Vyst_soubor) - 35, 36);
               Form1.StaticText3.Hint:= Form1.Vyst_soubor;
             end;
        end;
    end
  else
    begin
      // nastaveni vychozi cesty
      Form1.OpenDialog1.InitialDir:= ExtractFilePath (Form1.Vyst_soubor);
      Form1.OpenDialog1.FileName:= ExtractFileName (Form1.Vyst_soubor);

      if Form1.OpenDialog1.Execute then
      if FileExists (Form1.OpenDialog1.FileName) and IsValidFile (Form1.OpenDialog1.FileName) then
        begin
           Form1.Vyst_soubor:= ChangeFileExt(Form1.OpenDialog1.FileName,'.pcv');
           if Length (Form1.Vyst_soubor) < 40 then Form1.StaticText3.Caption:= Form1.Vyst_soubor
           else
             begin
               Form1.StaticText3.Caption:= Copy (Form1.Vyst_soubor, 1, 3) + '...' + Copy (Form1.Vyst_soubor, Length (Form1.Vyst_soubor) - 35, 36);
               Form1.StaticText3.Hint:= Form1.Vyst_soubor;
             end;
        end
      else Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_BAD_FILE2', 'The selected file is not valid backup file.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);
    end;
end;


//******************************************************************************
// function IsRunning
//
// - detekce spustene Mozilly
//******************************************************************************

function IsRunning: boolean;
var Procesy: TStringList;
    I: integer;
    Vysledek: boolean;
begin
  I:= 0;
  Vysledek:= false;
  if OSVersion = 7 then         // Windows NT
    begin
      Procesy:= GetProcessListNT;
      While I <= Procesy.Count-1 do
        begin
          case Form1.Typ_programu of
            1: begin
                 if Procesy[I] = 'mozilla.exe' then Vysledek:= true;
                 if Procesy[I] = 'Netscp.exe' then Vysledek:= true;
               end;
            2: begin
                 if Procesy[I] = 'MozillaFirebird' then Vysledek:= true;
                 if Procesy[I] = 'MozillaFirebird.exe' then Vysledek:= true;
                 if Procesy[I] = 'MOZILL~1.EXE' then Vysledek:= true;
               end;
            3: if Procesy[I] = 'thunderbird.exe' then Vysledek:= true;
          end;
          I:= I + 1;
        end;
    end
  else
    begin
      Procesy:= GetProcessList;     // vsechny Windows krome NT
      While I <= Procesy.Count-1 do
        begin
          case Form1.Typ_programu of
            1: begin
                 if Procesy[I] = 'mozilla.exe' then Vysledek:= true;
                 if Procesy[I] = 'Netscp.exe' then Vysledek:= true;
               end;
            2: begin
                 if Procesy[I] = 'MozillaFirebird' then Vysledek:= true;
                 if Procesy[I] = 'MozillaFirebird.exe' then Vysledek:= true;
                 if Procesy[I] = 'MOZILL~1.EXE' then Vysledek:= true;
               end;
            3: if Procesy[I] = 'thunderbird.exe' then Vysledek:= true;
          end;
          I:= I + 1;
        end;
    end;

  Result:= Vysledek;
end;


//******************************************************************************
// function IsValidFile
//
// - detekce platnosti souboru zalohy
//******************************************************************************

function IsValidFile (Soubor: string):boolean;
var F: textfile;
    S: string;
    Revize: byte;
    Vystup: boolean;
begin
  Vystup:= false;
  try
    if FileExists (Soubor) = true then begin

    // testovani na stary typ souboru
    AssignFile (F, Soubor);
    Reset (F);
      Readln (F, S);
      S:= Trim (S);
      if S = 'Mozilla Backup' then
        begin
          Readln (F, S);
          S:= Trim (S);
          Delete (S, 1, 7);
          S:= Trim (S);
          Revize:= StrToInt (S);
          if Form1.Typ_programu = Revize then
            begin
              Form1.Verze_souboru:= 1;
              Vystup:= true;
            end;
        end;
    CloseFile (F);

    if Vystup = false then
      begin
        // testovani na novy typ souboru
        Form1.ZipMaster1.ZipFileName:= Soubor;

        Form1.ZipMaster1.FSpecArgs.Add('indexfile.txt');
        Form1.ZipMaster1.ExtrBaseDir:= GetSpecialDir (2);

        if Form1.ZipMaster1.Extract = 0 then
          begin
            Form1.Verze_souboru:= 2;
            Vystup:= true;
          end;
      end;

    // prirazeni vysledku
    Result:= Vystup;

    end;

  except
    on E:EInOutError do     // nastala nejaka vyjimka
      begin
        Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_NOT_FOUND', 'A critical error occurred while accessing the file. The program will exit.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);
        Halt (1);
      end;
  end;
end;


//******************************************************************************
// procedure NastavCheckboxy
//
// - nastavi checkboxy
//******************************************************************************

procedure NastavCheckboxy;
var I: integer;
begin
  for I:= 1 to Form1.GroupBox3.ControlCount - 1 do
    begin
      if Form1.GroupBox3.Controls[I] is TCheckBox then
      TCheckBox(Form1.GroupBox3.Controls[I]).Checked:= false;
    end;

  for I:= 1 to Form1.GroupBox3.ControlCount - 1 do
    begin
      if Form1.GroupBox3.Controls[I] is TCheckBox then
      TCheckBox(Form1.GroupBox3.Controls[I]).Enabled:= true;
    end;
end;


//******************************************************************************
// function Over_profil
//
// - funkce overi, zda-li je zadany profil platny
//
// Vstup: Adresar - adresar s profilem
// Vystup: - je platny ci neni
//******************************************************************************

function Over_profil (Adresar: string):boolean;
var Vyhledej: TSearchRec;
begin
  Over_profil:= false;
  if FindFirst (Adresar + '\*.*', $00000010, Vyhledej) = 0 then
    begin
      Repeat
        if FileExists (Adresar + '\' + Vyhledej.Name + '\prefs.js') then Over_profil:= true;
      Until FindNext (Vyhledej) <> 0;
      SysUtils.FindClose (Vyhledej);
    end;
end;


//******************************************************************************
// procedure Over_program
//
// - detekce, zda-li byl nalezen nejaky program. Kdyz ne, program je ukoncen
//******************************************************************************

procedure Over_program;
begin
  if Form1.ListBox1.Count = 0 then
    begin
      Form1.Chyba:= true;
      Form1.ListBox1.Items.Add(TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_NO_PROGRAM', 'No program was found'));
      Form1.Button1.Visible:= false;
      Form1.Button3.Visible:= false;
      Form1.Button2.Caption:= TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_BUTTON_KONEC', 'Exit');
    end;                                         
end;


//******************************************************************************
// procedure Over_vyber
//
// - overi, zda-li je vybrana nejaka aplikace pro zalohovani (resp. obnovu)
//******************************************************************************

procedure Over_vyber;
begin
  if Form1.ListBox1.Items.Strings[0] <> TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_NO_PROGRAM', 'No program was found') then
    begin
      if not Form1.ListBox1.ItemIndex >= 0 then Form1.Button1.Enabled:= false
      else Form1.Button1.Enabled:= true;
    end;
end;


//******************************************************************************
// procedure Over_vyber_profilu
//
// - overi, zda-li je vybran nejaky profil
//******************************************************************************

procedure Over_vyber_profilu;
begin
  if Form1.ListBox2.ItemIndex >= 0 then Form1.Button1.Enabled:= true
  else Form1.Button1.Enabled:= false;
end;

//******************************************************************************
// procedure Ukonceni_pogramu
//
// - ukonci programu stisknutim krizku na formulari
//
// Vstup: CanClose - informace o uzavreni formulare
//******************************************************************************

procedure Ukonceni_programu (var CanClose: boolean);
begin
  if (Form1.Panel6.Visible = false) and (Form1.Chyba = false) then
    begin
      if Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_END_TEXT', 'The operation is not finished. Do you really want to exit the program?')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_END_PROGRAM', 'Exit the program')), MB_YESNO + MB_ICONQUESTION) = IDNO then
      CanClose:= false else
    end;
end;


//******************************************************************************
// function Zacatek_zalohovani
//
// - informace o tom, zda-li se muze zacit se zalohovanim (resp. obnovou)
//******************************************************************************

function Zacatek_zalohovani: boolean;
var Detekce: boolean;
begin
  Detekce:= false;
  While (IsRunning) and (Detekce = false) do
    begin
      case Form1.Typ_programu of
        1: if Application.MessageBox(pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_DETEKCE_MOZILLA', 'The Mozilla (Netscape) program is running. Exit it and click the Again button.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'LANG_WARNING')), MB_RETRYCANCEL + MB_ICONERROR) = IDCANCEL then Detekce:= true;
        2: if Application.MessageBox(pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_DETEKCE_FIREBIRD', 'The Mozilla Firebird program is running. Exit it and click the Again button.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'LANG_WARNING')), MB_RETRYCANCEL + MB_ICONERROR) = IDCANCEL then Detekce:= true;
        3: if Application.MessageBox(pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_DETEKCE_THUNDERBIRD', 'The Mozilla Thunderbird program is running. Exit it and click the Again button.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'LANG_WARNING')), MB_RETRYCANCEL + MB_ICONERROR) = IDCANCEL then Detekce:= true;
      end;
    end;
  if Detekce = true then
    begin
      case Form1.Typ_programu of
        1: Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_DETEKCE_MOZILLA2', 'You must exit the Mozilla (Netscape) program before backing up. The program will exit.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);
        2: Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_DETEKCE_FIREBIRD2', 'You must exit the Mozilla Firebird program before backing up. The program will exit.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);
        3: Application.MessageBox (pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_DETEKCE_THUNDERBIRD2', 'You must exit the Mozilla Thunderird program before backing up. The program will exit.')), pchar (TbsCorePolyglot.GetCorePolyglot.GetString ('TForm1', 'LANG_WARNING', 'Warning')), MB_OK + MB_ICONWARNING);      

      end;
      Halt (1);
    end;
  if Detekce = true then Result:= false else Result:= true;
end;

end.
